import 'package:flutter/material.dart';
import 'package:latlong2/latlong.dart';

// Sensor holds data about a single sensor
class Sensor {
  int id;
  String type;
  bool active;

  Sensor({required this.id, required this.type, required this.active});

  factory Sensor.fromJson(Map<String, dynamic> json) {
    return Sensor(
      id: json['ID'],
      type: json['type'],
      active: json['active'],
    );
  }
}

// DateAndTime holds the date and time for a single measurement
class DateAndTime {
  int year;
  int month;
  int day;
  int hour;
  int minute;

  DateAndTime({
    required this.year,
    required this.month,
    required this.day,
    required this.hour,
    required this.minute,
  });

  factory DateAndTime.fromJson(Map<String, dynamic> json) {
    return DateAndTime(
      year: json['year'],
      month: json['month'],
      day: json['day'],
      hour: json['hour'],
      minute: json['minute'],
    );
  }
}

// Measurement holds data related to a singular measurement taken
// at a given time
class Measurement {
  double longitude;
  double latitude;
  DateAndTime datetime;
  Sensor sensor;
  double precipitation;
  double thickness;
  double maxWeight;
  double safetyLevel;
  double accuracy;

  Measurement({
    required this.longitude,
    required this.latitude,
    required this.datetime,
    required this.sensor,
    required this.precipitation,
    required this.thickness,
    required this.maxWeight,
    required this.safetyLevel,
    required this.accuracy,
  });

  factory Measurement.fromJson(Map<String, dynamic> json) {
    return Measurement(
      longitude: json['longitude'],
      latitude: json['latitude'],
      datetime: DateAndTime.fromJson(json['datetime']),
      sensor: Sensor.fromJson(json['sensor']),
      precipitation: json['precipitation'],
      thickness: json['thickness'],
      maxWeight: json['max_weight'],
      safetyLevel: json['safety_level'],
      accuracy: json['accuracy'],
    );
  }
}

// MarkerTemplate holds all data required for rendering a marker
class MarkerTemplate {
  Measurement geoData;
  LatLng location;
  double size;
  Color color;

  MarkerTemplate({
    required this.geoData,
    required this.location,
    required this.size,
    required this.color
  });

  factory MarkerTemplate.fromJson(Map<String, dynamic> json) {
    // Parse from JSON string to type Color
    Color parsedColor = parseColor(json['color']);

      return MarkerTemplate(
        geoData: Measurement.fromJson(json['geo_data']),
        location: LatLng(json['latitude'], json['longitude']),
        size: json['size'],
        color: parsedColor,
      );
    }

    // parseColor parses the color strings into Colors types
    static Color parseColor(String colorString) {
    colorString = colorString.toLowerCase();
      switch (colorString) {
        case 'yellow':
          return Colors.yellow;
        case 'red':
          return Colors.red;
        case 'green':
          return Colors.green;
        default:
          return Colors.black; // Default color if unrecognized
      }
    }
}
