CREATE TABLE Measurement (
    MeasurementID INT PRIMARY KEY,
    SensorID INT,
    TimeMeasured DATETIME,
    FOREIGN KEY (SensorID) REFERENCES Sensor(SensorID)
);

CREATE TABLE Sensor (
    SensorID INTEGER PRIMARY KEY,
    SensorType TEXT CHECK(SensorType IN ('LiDar', 'Magnetic', 'Other')),
    Active BOOLEAN
);

CREATE TABLE Data (
    MeasurementID INT,
    Latitude FLOAT,
    Longitude FLOAT,
    IceTop FLOAT,
    IceBottom FLOAT,
    CalculatedThickness FLOAT,
    Accuracy FLOAT,
    PRIMARY KEY (MeasurementID, Longitude, Latitude),
    FOREIGN KEY (MeasurementID) REFERENCES Measurement(MeasurementID)
);

INSERT INTO Sensor (SensorID, SensorType, Active) VALUES
(1, 'LiDar', 1),
(2, 'Magnetic', 1),
(3, 'Other', 0);

INSERT INTO Measurement (MeasurementID, SensorID, TimeMeasured) VALUES
(1, 2, '2024-01-01 10:00:00'),
(2, 2, '2024-02-04 11:00:00'),
(3, 1, '2024-02-13 12:00:00');

-- Measurement 1
INSERT INTO Data (MeasurementID, Latitude, Longitude, IceTop, IceBottom, CalculatedThickness, Accuracy) VALUES
(1, 60.7066, 10.9771, 8.0, 3.0, 5.0, 1.0),
(1, 60.7066, 10.9772, 7.5, 2.5, 5.0, 1.0),
(1, 60.7067, 10.9773, 7.0, 2.0, 5.0, 1.0);

-- Measurement 2
INSERT INTO Data (MeasurementID, Latitude, Longitude, IceTop, IceBottom, CalculatedThickness, Accuracy) VALUES
(2, 60.6366, 10.8171, 7.2, 2.2, 5.0, 1.5),
(2, 60.6367, 10.8172, 7.0, 2.0, 5.0, 1.5);

-- Measurement 3
INSERT INTO Data (MeasurementID, Latitude, Longitude, IceTop, IceBottom, CalculatedThickness, Accuracy) VALUES
(3, 60.7366, 10.8471, 7.5, 2.5, 5.0, 2.5),
(3, 60.7367, 10.8472, 7.0, 2.0, 5.0, 2.5);
